#!/usr/bin/perl
use warnings;
use strict;
use Test::More;
use Fobaccess;

my @good_array = ('A01101', '0123456789ABCDEF');
ok(Fobaccess::validate_input(\@good_array),
   'Two inputs expected for validate_input()');

my @bad_array_oneval = ('one value');
like(Fobaccess::validate_input(\@bad_array_oneval),
   qr/Usage/, 'One input fails as expected for validate_input()');

my @bad_array_threevals = ('three values', 'three values', 'three values');
like(Fobaccess::validate_input(\@bad_array_threevals),
   qr/Usage/, 'Three inputs fail as expected for validate_input()');

like(Fobaccess::test_access(\@bad_array_oneval),
   qr/Invalid number/, 'One input fails as expected for test_access()');

like(Fobaccess::test_access(\@bad_array_threevals),
   qr/Invalid number/, 'One input fails as expected for test_access()');

like(Fobaccess::test_access(\@good_array),
   qr/Yes/, 'Two valid inputs OK for test_access()');

like(Fobaccess::test_access( ['notauser', 'not_a_door']),
   qr/No/, 'Two invalid inputs for test_access() fail as expected');

like(Fobaccess::validate_door_format(), qr/Not enough inputs/,
   'Less than one input fails for validate_door_format() as expected');

like(Fobaccess::validate_door_format('two inputs', 'two inputs'), qr/Extra inputs/,
   'More than one input fails for validate_door_format() as expected');

like(Fobaccess::validate_door_format('A123'), qr/too few/,
   'Too few chars on input fails for validate_door_format() as expected');

like(Fobaccess::validate_door_format('0123456789ABCDEF'), qr/too many/,
   'Too many chars on input fails for validate_door_format() as expected');

like(Fobaccess::validate_door_format('A1234A'), qr/Not a door/,
   'Bad door chars on input fails for validate_door_format() as expected');

like(Fobaccess::validate_door_format('Ab1234'), qr/Not a door/,
   'Bad floor chars on input fails for validate_door_format() as expected');

like(Fobaccess::validate_door_format('A12345'), qr/Valid door/,
   'Good data works for validate_door_format() as expected');

like(Fobaccess::validate_door_format('Z98765'), qr/Valid door/,
   'Good data works for validate_door_format() as expected');

like(Fobaccess::validate_fob_format(), qr/Not enough inputs/,
   'Less than one input fails for validate_fob_format() as expected');

like(Fobaccess::validate_fob_format('two inputs', 'two inputs'), qr/Extra inputs/,
   'More than one input fails for validate_fob_format() as expected');

like(Fobaccess::validate_fob_format('0123456789ABCDEF0'), qr/Not a valid fob/,
   'Too few chars on input fails for validate_fob_format() as expected');

like(Fobaccess::validate_fob_format('0123456789ABCDE'), qr/Not a valid fob/,
   'Too many chars on input fails for validate_fob_format() as expected');

like(Fobaccess::validate_fob_format('Z123456789ABCDEF'), qr/non-hex/,
   'Bad (non-hex) data on input fails for validate_fob_format() as expected');

like(Fobaccess::validate_fob_format('0123456789ABCDEF'), qr/Valid fob/,
   'Good data works for validate_fob_format() as expected');

like(Fobaccess::validate_fob_format('ABCDEF0123456789'), qr/Valid fob/,
   'Good data works for validate_door_format() as expected');


done_testing;
