package Fobaccess;

use warnings;
use strict;

sub validate_input {
 # UNLESS WE HAVE TWO INPUTS, SHOW DIE WITH USAGE.
 if (scalar @_ != 2) {
  my $usage =<<"EOT";
Usage: $0 DOORNUM FOBNUM
 DOORNUM is a number of format BFFDDD (BUILDING, FLOOR, NUMBER - e.g. A01101)
 FOBNUM is 16 hex digits.
EOT
  return $usage;
 }
return 'OK';
}

sub test_access {
 if (scalar @_ != 2)
  { return "Invalid number of inputs"; }

 my $door_number = shift;
 my $fob_number  = shift;
 if (($fob_number eq '0123456789ABCDEF') && ($door_number eq 'A01101'))
  { return 'Yes'; }
 elsif (($fob_number eq '0123456789ABCDEF') &&	($door_number eq 'A01102'))
  { return 'Yes'; }
 else { return 'No'; }
}

sub validate_door_format {
 if (scalar @_ > 1)    { return "Extra inputs to validate_door_format"; }
 elsif (scalar @_ < 1) { return "Not enough inputs to validate_door_format"; }

 my $input_door = shift;
 if (length $input_door > 6)    { return "Not a valid door; too many chars"; }
 elsif (length $input_door < 6) { return "Not a valid door; too few chars"; }

 unless ($input_door =~ /^[a-z]\d{5}$/i)
  { return "Not a door; does not match BFFDDD"; }

 return "Valid door";
}

sub validate_fob_format {
 if (scalar @_ > 1)    { return "Extra inputs to validate_fob_format"; }
 elsif (scalar @_ < 1) { return "Not enough inputs to validate_fob_format"; }

 my $input_fob = shift;
 if (length $input_fob > 16)    { return "Not a valid fob; too many chars"; }
 elsif (length $input_fob < 16) { return "Not a valid fob; too few chars"; }

 unless ($input_fob =~ /^[\da-f]{16}$/i)
  { return "Not a fob; at least one non-hex char"; }

 return "Valid fob";
}


1;
